@@ -3,7 +3,7 @@ package YAML::LibYAML::API;
 use strict;
 use warnings;
 
-our $VERSION = '0.013_001'; # TRIAL VERSION
+our $VERSION = '0.013_002'; # TRIAL VERSION
 
 use YAML::PP::Common qw/
     YAML_ANY_SCALAR_STYLE YAML_PLAIN_SCALAR_STYLE
@@ -159,10 +159,18 @@ YAML::LibYAML::API - Wrapper around the C libyaml library
     YAML::LibYAML::API::XS::parse_filehandle_events($fh, $events);
 
     # emit
-    my $yaml = YAML::LibYAML::API::XS::emit_string_events($events);
+    my $yaml = YAML::LibYAML::API::XS::emit_string_events($events, {
+        indent => 2,
+        width => 80,
+        unicode => 1, # emit unicode
+    });
     # or:
-    YAML::LibYAML::API::XS::emit_file_events($filename, $events);
-    YAML::LibYAML::API::XS::emit_filehandle_events($fh, $events);
+    my $options = {
+        indent => 2,
+        width => 80,
+    };
+    YAML::LibYAML::API::XS::emit_file_events($filename, $events, $options);
+    YAML::LibYAML::API::XS::emit_filehandle_events($fh, $events, $options);
 
 =head1 DESCRIPTION
 
@@ -176,8 +184,6 @@ of nodes. There's no wrapper for these functions yet.
 This is just one of the first releases. The function names will eventually be
 changed.
 
-See also L<YAML::LibYAML::API::Parser> for an OOP interface.
-
 The sources of C<libyaml-dev> are included in this distribution. You can
 build this module with the system libyaml instead, if you remove the libyaml
 sources and call C<Makefile.PL> with C<WITH_SYSTEM_LIBYAML=1>.
